grab.spider.queue_backend.mongodb — Grab 0.6.41 documentation

# `grab.spider.queue_backend.mongodb`

## Module Contents

### Classes

`MongodbTaskQueue` |

### Attributes

`LOG` |

grab.spider.queue_backend.mongodb.LOG

class grab.spider.queue_backend.mongodb.MongodbTaskQueue(connection_args: None | dict[str, Any] = None, collection_name: None | str = None, database_name: str = 'grab_spider')

  Bases: `grab.spider.queue_backend.base.BaseTaskQueue`

  size() → int
  put(task: grab.spider.task.Task, priority: int, schedule_time: None | datetime = None) → None
  get() → grab.spider.task.Task
  clear() → None
  close() → None